SWDEV-339657 - Update catch codes with correct coordinates (#2735)

Change-Id: I8ca78d770a742bf6c2abede494759caa923fcc19
Этот коммит содержится в:
ROCm CI Service Account
2022-06-15 23:28:10 +05:30
коммит произвёл GitHub
родитель 0b05268be2
Коммит d31aca651d
8 изменённых файлов: 19 добавлений и 19 удалений
+1 -1
Просмотреть файл
@@ -57,7 +57,7 @@ Testcase Scenarios :
* Kernel Functions to copy.
*/
static __global__ void copy_ker_func(int* a, int* b) {
int tx = hipBlockIdx_x*hipBlockDim_x + hipThreadIdx_x;
int tx = blockIdx.x*blockDim.x + threadIdx.x;
if (tx < LEN) b[tx] = a[tx];
}